@@ -74,6 +74,15 @@ class TelegramBot(MultiBot[TelegramClient]):
         self.bot_client.add_event_handler(self._on_inline_query_raw, telethon.events.InlineQuery)
         self.bot_client.add_event_handler(self._on_new_message_raw, telethon.events.NewMessage)
 
+    @return_if_first_empty(exclude_self_types='TelegramBot', globals_=globals())
+    async def _create_bot_message_from_telegram_bot_message(self, original_message: constants.TELEGRAM_MESSAGE, message: Message, contents: Any = None) -> Message | None:
+        original_message._sender = await self.bot_client.get_entity(self.bot_id)
+        original_message._chat = message.chat.original_object
+        bot_message = await self._get_message(original_message)
+        bot_message.contents = contents or []
+        bot_message.save()
+        return bot_message
+
     @return_if_first_empty(exclude_self_types='TelegramBot', globals_=globals())
     async def _create_chat_from_telegram_chat(self, telegram_chat: constants.TELEGRAM_CHAT) -> Chat | None:
         if is_group := not isinstance(telegram_chat, constants.TELEGRAM_USER):
@@ -90,15 +99,6 @@ class TelegramBot(MultiBot[TelegramClient]):
             original_object=telegram_chat
         )
 
-    @return_if_first_empty(exclude_self_types='TelegramBot', globals_=globals())
-    async def _create_bot_message_from_telegram_bot_message(self, original_message: constants.TELEGRAM_MESSAGE, message: Message, content: Any = None) -> Message | None:
-        content = content or {}
-        original_message._sender = await self.bot_client.get_entity(self.bot_id)
-        original_message._chat = message.chat.original_object
-        bot_message = await self._get_message(original_message)
-        bot_message.contents = [content]
-        return bot_message
-
     @return_if_first_empty(exclude_self_types='TelegramBot', globals_=globals())
     async def _create_user_from_telegram_user(self, original_user: constants.TELEGRAM_USER, group_id: int = None) -> User | None:
         try:
@@ -203,11 +203,6 @@ class TelegramBot(MultiBot[TelegramClient]):
     # ---------------------------------------------- #
     #                    HANDLERS                    #
     # ---------------------------------------------- #
-    @find_message
-    async def _on_button_press_raw(self, message: Message):
-        for registered_button_callback in self._registered_button_callbacks:
-            await registered_button_callback(message)
-
     @find_message
     async def _on_inline_query_raw(self, message: Message):
         await super()._on_new_message_raw(message)
@@ -325,6 +320,8 @@ class TelegramBot(MultiBot[TelegramClient]):
         edit=False,
     ) -> Message | None:
         file = await self._prepare_media_to_send(media)
+        if not text and not file:
+            return
 
         if send_as_file is None:
             word_matches = flanautils.cartesian_product_string_matching(message.text, constants.KEYWORDS['send_as_file'], min_ratio=0.65)
@@ -338,7 +335,8 @@ class TelegramBot(MultiBot[TelegramClient]):
         kwargs = {
             'file': file,
             'force_document': send_as_file,
-            'buttons': buttons or None
+            'buttons': buttons or None,
+            'parse_mode': 'html'
         }
 
         if message.is_inline and media:
@@ -354,8 +352,7 @@ class TelegramBot(MultiBot[TelegramClient]):
                     bot_message.contents.clear()
                     bot_message.save()
                     original_message = await self.bot_client.send_message(message.chat.original_object, text, **kwargs)
-                    bot_message = await self._create_bot_message_from_telegram_bot_message(original_message, message, content=getattr(media, 'content', None))
-                    bot_message.save()
+                    await self._create_bot_message_from_telegram_bot_message(original_message, message, contents=[getattr(media, 'content', None)])
             elif media.type_ is MediaType.IMAGE:
                 message.contents.append(message.original_event.builder.photo(file))
             else:
@@ -370,7 +367,7 @@ class TelegramBot(MultiBot[TelegramClient]):
             return message
         else:
             original_message = await self.bot_client.send_message(message.chat.original_object, text, **kwargs)
-            return await self._create_bot_message_from_telegram_bot_message(original_message, message, content=getattr(media, 'content', None))
+            return await self._create_bot_message_from_telegram_bot_message(original_message, message, contents=[getattr(media, 'content', None)])
 
     @inline
     async def send_inline_results(self, message: Message):
